from setuptools import setup

setup(name='ftThanos',
version="0.0.25",
description="A client for 42 API",
author="Thanos 42",
author_email="thanos@42paris.fr",
packages=["ftThanos"],
install_requires=["requests","python-dotenv"],
)
